# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['oanda_candles']

package_data = \
{'': ['*']}

install_requires = \
['magic-kind>=0.2.1,<0.3.0',
 'pytest>=5.4.2,<6.0.0',
 'requests>=2.23.0,<3.0.0',
 'time-int>=0.0.2,<0.0.3']

setup_kwargs = {
    'name': 'oanda-candles',
    'version': '0.0.1',
    'description': 'Oanda forex candle API built on top of oandapyV20',
    'long_description': '# oanda-candles\nOanda forex candle API built on top of oandapyV20\n\n### Oanda Access Token\nUsing this package requires an access token to a user\'s\nOanda brokerage account. This module only uses the token to\nrequest candle data, but such tokens can be used to make\ntrades on the account. It is recommended that access\ntokens from a demo as opposed to a live accounts be used.\n \nDemo account tokens can be generated by a signed in user here:\n\nhttps://www.oanda.com/demo-account/tpa/personal_token\n\n### Quick Example\nSupposing that `token` is set to an Oanda access token, one could print\nthe opening bid price of the latest 100 trading hours for the Aussie like this: \n\n```python\nfrom oanda_candles import CandleRequester, Pair, Gran\n\naud_usd = Pair("audusd")\nrequester = CandleRequester(token, aud_usd, Gran.H1)\ncandles = requester.request(count=100)\n\nfor candle in candles:\n    print(candle.bid.o)\n```\n\n\n### Summary of Basic Usage\n1. A `CandleRequester` object is initialized with a token, forex pair, and granularity.\n1. Its `request` method is called specifying starting time, ending time, and/or count of the candle range desired.\n1. This returns a `CandleSequence` object containing `Candle` objects as well as the pair and granularity.\n1. Each `Candle` has three `Ohlc` objects, one for Bid, Mid, and Ask prices.\n1. The `Ohlc` objects have open, high, low, and close `Price` objects\n\n### Understanding Request Ranges\nThe `CandleRequester.request()` has `start`, `end`, and `count`\noptional parameters used to specify how many candles and from when.\n\n| parameter | valid types | valid range | default |\n|: --- |: --- |:----|:----|\n| start | TimeInt, datetime, None | epoch to now | None |\n| end | TimeInt, datetime, None | epoch to now | now | \n| count | int, None | 1 to 5000 | 500 |\n\nIt does not make sense to set all three of these parameters, but you can\nspecify any single one of them, or any two of them, or none of them.\nThe behavior for when they are set or unset is shown in this table:\n\n| start | end | count | behavior |\n|: --- |: --- |:----|: --- |\n| -- | -- | -- | Get latest 500 candles |\n| -- | -- | set | Get latest count candles |\n| -- | set | -- | Get last 500 candles up until the end time |\n| -- | set | set | Get last count candles up until the end time | \n| set | -- | -- | Get the first 500 candles from start time | \n| set | -- | set | Get the first count candles from start time |\n| set | set | -- | Get candles from start to end times | \n| set | set | set | ValueError (there might be a different count in the range) | \n',
    'author': 'Andrew Allaire',
    'author_email': 'andrew.allaire@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aallaire/oanda-candles',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
